# Script cleans ESP partition and NVRAM for ViPNet SafeBoot installation/update.
# Usage:
#  cleaner.nsh <EspPartition> (all | confdb | log | etalons | modules)

echo -off

set -v EspPartition %1
set -v CleanMode %2

set -v InstallPkgDir itinstall
set -v EfiDir EFI
set -v EspItDir %EfiDir%\Infotecs
set -v EspItLogDir %EspItDir%\log
set -v EspItConfDBDir %EspItDir%\confdb
set -v EspItEtalonsDir %EspItDir%\etalons
set -v ItVariableGuid 939481D1-AFFF-45DD-8EEB-D4D7B10D2E8A

if /i not %CleanMode% == all and not %CleanMode% == confdb and not %CleanMode% == log and not %CleanMode% == etalons and not %CleanMode% == modules then
  echo Invalid cleaner.nsh arguments
  exit /b 0x1
endif

if exist clean_storage_var.nsh then
  set -v CleanStorageVarScipt clean_storage_var.nsh
else
  if exist %InstallPkgDir%\clean_storage_var.nsh then
    set -v CleanStorageVarScipt %InstallPkgDir%\clean_storage_var.nsh
  endif
endif

# Log cleaning
if /i %CleanMode% == log or %CleanMode% == all then
  %CleanStorageVarScipt% ItLog
  rm -q %EspPartition%:\%EspItLogDir%\* > NUL

  dmpstore -d ItEnterToBiosSetupBlocked -guid %ItVariableGuid% > NUL
  dmpstore -d ItPassThroughModeBlocked -guid %ItVariableGuid% > NUL
  dmpstore -d ItPassThroughModeActivated -guid %ItVariableGuid% > NUL
endif

# ConfDB cleaning
if /i %CleanMode% == confdb or %CleanMode% == all then
  %CleanStorageVarScipt% ItConfDB
  rm -q %EspPartition%:\%EspItConfDBDir%\* > NUL

  dmpstore -d ItEarlyConfDB -guid %ItVariableGuid% > NUL
  dmpstore -d ItAllowToEnterBiosSetup -guid %ItVariableGuid% > NUL
  dmpstore -d ItS3bsData -guid %ItVariableGuid% > NUL
endif

# etalons cleaning
if /i %CleanMode% == etalons or %CleanMode% == all then
  # ConfDB etalons clean not supported
  rm -q %EspPartition%:\%EspItEtalonsDir%\* > NUL
endif

# modules cleaning
if /i %CleanMode% == modules or %CleanMode% == all then
  rm -q %EspPartition%:\%EspItDir%\*.efi > NUL
endif

if /i %CleanMode% == all then
  rm -q %EspPartition%:\%EspItDir% > NUL
endif

:Exit
exit /b 0x0
