# Script gets diagnostic information for ViPNet SafeBoot installation.
# Usage:
#  diaginfo.nsh <InstallPkgPartition> [<InstallProfile>]

echo -off

set -v InstallPkgPartition %1
if x%2 == x then
  set -v InstallProfile common_base
else
  set -v InstallProfile %2
endif

set -v InstallPkgDir itinstall
set -v ToolsDir %InstallPkgDir%\tools
set -v NvramChecker %ToolsDir%\NvramChecker.efi
set -v BiosInfo %ToolsDir%\BiosInfo.efi
set -v BiosTool %ToolsDir%\BiosTool.efi
set -v FlasherWrapper %InstallPkgDir%\flasher.nsh
set -v BiosToolIni %InstallPkgDir%\modules\biostool.ini
set -v FfsModulesDir %InstallPkgDir%\modules\ffs
set -v PlatformDir %InstallPkgDir%\platform
set -v NvramCheckerLog %PlatformDir%\nvramchecker.log
set -v BiosInfoLog %PlatformDir%\biosinfo.log
set -v FlasherLog %PlatformDir%\flasher.log
set -v BiosToolLog %PlatformDir%\biostool.log
set -v CurBiosRegion %PlatformDir%\cur_fw_br.bin
set -v ModBiosRegion %PlatformDir%\mod_fw_br.bin

echo ViPNet SafeBoot pre-installation diagnostic start

#%InstallPkgPartition%:

if exist %CurBiosRegion% then
  rm -q %CurBiosRegion%
endif
if exist %ModBiosRegion% then
  rm -q %ModBiosRegion%
endif

echo Getting NVRAM free space information...
%NvramChecker% > %NvramCheckerLog%

echo Getting platform information by BiosInfo...
%BiosInfo% > %BiosInfoLog%

echo Getting flasher information...
%FlasherWrapper% info %ToolsDir% > %FlasherLog%

echo Getting original BIOS region...
%FlasherWrapper% read %CurBiosRegion% %ToolsDir%

echo Trying to integrate ViPNet SafeBoot modules to original BIOS region...
echo UEFI modules integration process may be so long (several minutes). Please wait...
cd %ToolsDir%
# absolute paths used below because of 'cd' command above:
# it needs for BiosTool correct call - install.dat file must be in current directory
%InstallPkgPartition%:\%BiosTool% -i %InstallPkgPartition%:\%CurBiosRegion% -o %InstallPkgPartition%:\%ModBiosRegion% --profile %InstallProfile% --configfile %InstallPkgPartition%:\%BiosToolIni% --pmdzdir %InstallPkgPartition%:\%FfsModulesDir% --debug > %InstallPkgPartition%:\%BiosToolLog%
map -r > NUL
%InstallPkgPartition%:
cd \
# TODO?: type %BiosToolLog%

echo Platform diagnostic information gathered at the %PlatformDir%

:Exit
