# Script installs ViPNet SafeBoot to SPI Flash BIOS region and ESP partition.
# Usage:
#  installer.nsh <InstallPkgPartition> <EspPartition> (interactive | not_interactive) [<InstallProfile>]

echo -off

if x%1 == x or x%2 == x or x%3 == x then
  echo Invalid installer.nsh arguments
  exit /b 1
endif
if /i not %3 == interactive and not %3 == not_interactive then
  echo Invalid installer.nsh arguments
  exit /b 1
endif

set -v InstallPkgPartition %1
set -v EspPartition %2
set -v InteractivityMode %3
if x%4 == x then
  set -v InstallProfile common_full
else
  set -v InstallProfile %4
endif

set -v InstallPkgDir itinstall
set -v InstallPkgParamsDir %InstallPkgDir%\params
set -v CleanAllFile %InstallPkgParamsDir%\clean_all
set -v CleanLogFile %InstallPkgParamsDir%\clean_log
set -v CleanConfDBFile %InstallPkgParamsDir%\clean_confdb
set -v CleanEtalonsFile %InstallPkgParamsDir%\clean_etalons
set -v CleanModulesFile %InstallPkgParamsDir%\clean_modules
set -v InstallPkgStatusDir %InstallPkgDir%\status
set -v InstalledFlagFile %InstallPkgStatusDir%\installed
set -v FailedFlagFile %InstallPkgStatusDir%\failed
set -v DeactivatedFlagFile %InstallPkgStatusDir%\deactivated
set -v InstallPkgImportDir %InstallPkgDir%\import
set -v ConfDBAutoImportFile %InstallPkgImportDir%\itsbdb_auto_import.bin
set -v ConfDBAutoImportSigFile %InstallPkgImportDir%\itsbdb_auto_import.sig
set -v ToolsDir %InstallPkgDir%\tools
set -v NvramChecker %ToolsDir%\NvramChecker.efi
set -v NvramReclaimer %ToolsDir%\NvramReclaimer.efi
set -v PlatformDir %InstallPkgDir%\platform
set -v NvramCheckerLog %PlatformDir%\nvramchecker.log
set -v NvramReclaimerLog %PlatformDir%\nvramreclaimer.log
set -v EfiDir EFI
set -v EspItDir %EfiDir%\Infotecs
set -v EspItBackupDir %EfiDir%\InfotecsBackup
set -v EspItConfDBDir %EspItDir%\confdb
set -v ItVariableGuid 939481D1-AFFF-45DD-8EEB-D4D7B10D2E8A

if /i not %InteractivityMode% == interactive then
  set -v InstallOrUpdateMode update
else
  set -v InstallOrUpdateMode install
endif

#%InstallPkgPartition%:

echo ESP backup phase...
if exist %EspPartition%:\%EspItDir% then
  if exist %EspPartition%:\%EspItBackupDir% then
    rm -q %EspPartition%:\%EspItBackupDir%\*
  else
    mkdir %EspPartition%:\%EspItBackupDir%
  endif
  cp -r -q %EspPartition%:\%EspItDir%\* %EspPartition%:\%EspItBackupDir%\ > NUL
  # TODO: create archive of EFI\Infotecs contents on installation disk
endif

echo Cleaning phase...
if exist %CleanAllFile% then
  %InstallPkgDir%\cleaner.nsh %EspPartition% all
else
  if exist %CleanLogFile% then
    %InstallPkgDir%\cleaner.nsh %EspPartition% log
  endif
  if exist %CleanConfDBFile% then
    %InstallPkgDir%\cleaner.nsh %EspPartition% confdb
  endif
  if exist %CleanEtalonsFile% then
    %InstallPkgDir%\cleaner.nsh %EspPartition% etalons
  endif
  if exist %CleanModulesFile% then
    %InstallPkgDir%\cleaner.nsh %EspPartition% modules
  endif
endif

dmpstore ItLogS00 -guid %ItVariableGuid% > NUL
if %lasterror% == 0x0 then
  set -v ItLogExists true
else
  set -v ItLogExists false
endif
dmpstore ItConfDBS00 -guid %ItVariableGuid% > NUL
if %lasterror% == 0x0 then
  set -v ItConfDBExists true
else
  set -v ItConfDBExists false
endif

# TODO: think about separate existence of ItLog and ItConfDB
if /i %ItLogExists% == false and %ItConfDBExists% == false then
  echo Trying to reclaim NVRAM...
  %NvramReclaimer% > %NvramReclaimerLog%

  echo Checking NVRAM free space...
  %NvramChecker% > %NvramCheckerLog%
  if not %lasterror% == 0x0 then
    type %NvramCheckerLog%
    goto ExitOnErrorWithRecovery
  endif
endif

echo Filesystem phase: preparing ESP...
%InstallPkgDir%\phase_fs.nsh %InstallPkgPartition% %EspPartition%

if not %lasterror% == 0x0 then
  goto ExitOnErrorWithRecovery
endif

echo Firmware phase: integration ViPNet SafeBoot modules to firmware image and writing it to SPI flash...
%InstallPkgDir%\phase_fw.nsh %InstallPkgPartition% %InstallProfile%

if not %lasterror% == 0x0 then
  # TODO: request for UEFI installation
  goto ExitOnErrorWithRecovery
endif

echo Filesystem phase: copying ViPNet SafeBoot modules to ESP...
# InstallProfile can be changed in phase_fw script in case of unsufficient free space in SPI flash
%InstallPkgDir%\phase_fs_mods.nsh %InstallPkgPartition% %EspPartition% %InstallProfile%

if not %lasterror% == 0x0 then
  goto ExitOnErrorWithRecovery
endif

if exist %ConfDBAutoImportFile% then
  if exist %ConfDBAutoImportSigFile% then
    echo Customization phase: ViPNet SafeBoot configuration DB will be imported at first start...
    cp -q %ConfDBAutoImportFile% %EspPartition%:\%EspItConfDBDir%\ > NUL
    cp -q %ConfDBAutoImportSigFile% %EspPartition%:\%EspItConfDBDir%\ > NUL
  endif
endif

echo -off >a %InstallPkgPartition%:\%InstalledFlagFile%
if /i %InstallOrUpdateMode% == install then
  echo -off >a %InstallPkgPartition%:\%DeactivatedFlagFile%
  echo ViPNet SafeBoot installed successfully
  echo Press 'q' key to cancel reboot or other key to reboot the system
  pause -q
  reset -c "ViPNet SafeBoot installed"
else
  echo ViPNet SafeBoot updated successfully
  echo System will be reboot automatically after 10s
  stall 10000000
  reset -c "ViPNet SafeBoot updated"
endif

:ExitOnErrorWithRecovery
echo Restoring to ESP backup...
if exist %EspPartition%:\%EspItDir% then
  rm -q %EspPartition%:\%EspItDir% > NUL
endif
if exist %EspPartition%:\%EspItBackupDir% then
  mv %EspPartition%:\%EspItBackupDir% %EspPartition%:\%EspItDir% > NUL
endif

:ExitOnError
echo -off >a %InstallPkgPartition%:\%FailedFlagFile%
if /i %InstallOrUpdateMode% == install then
  echo -off >a %InstallPkgPartition%:\%DeactivatedFlagFile%
endif
echo ViPNet SafeBoot installation/update error

if /i %InstallOrUpdateMode% == update then
  echo System will be reboot automatically after 10s
  stall 10000000
  reset -c "ViPNet SafeBoot update error"
endif

:Exit
