# Main script for request to diagnostic or installation phases.
# Executes by Shell 2.1 BT.
# Usage:
#  main.nsh (install | uninstall) (interactive | not_interactive)

echo -off

if x%1 == x or x%2 == x then
  echo Invalid main.nsh arguments
  exit /b 1
endif
if /i not %1 == install and not %1 == uninstall then
  echo Invalid main.nsh arguments
  exit /b 1
endif
if /i not %2 == interactive and not %2 == not_interactive then
  echo Invalid main.nsh arguments
  exit /b 1
endif

set -v InstallOrUninstallMode %1
set -v InteractivityMode %2

set -v InstallPkgDir itinstall
set -v CheckPkgScript %InstallPkgDir%\check_pkg.nsh
set -v InstallerScript %InstallPkgDir%\installer.nsh
set -v UninstallerScript %InstallPkgDir%\uninstaller.nsh
set -v InstallPkgDescriptionFile %InstallPkgDir%\description.txt
set -v ToolsDir %InstallPkgDir%\tools
set -v DriverUnloader %ToolsDir%\DriverUnloader.efi
set -v ExtNtfsDriver %InstallPkgDir%\modules\efi\ExtNtfs.efi
set -v ExtNtfsDriverLoaded false
set -v ShowInstallerTitle true
set -v CheckPkgScriptLog chkpkg.log
set -v EfiDir EFI
set -v EspItDir %EfiDir%\Infotecs

# change screen mode to fix potential Shell's scroll problem:
mode 128 40
cls 0

# find partition with installation package:
:FindInstallPkgPartition
for %i run (0 9 1)
  if exist fs%i:\%InstallPkgDir% then
    set -v InstallPkgPartition fs%i
    goto InstallPkgPartitionFound
  endif
endfor

echo ViPNet SafeBoot installation package not found...
goto Exit

:InstallPkgPartitionFound
# echo ViPNet SafeBoot installation partition found as %InstallPartition%

%InstallPkgPartition%:

#TODO: request for diagnostic phase (diaginfo.nsh)

if /i %ShowInstallerTitle% == true then
  if /i %InstallOrUninstallMode% == install then
    if /i not %InteractivityMode% == not_interactive then
      echo ViPNet SafeBoot installation:
      type %InstallPkgDescriptionFile%
      # echo "Press 'q' key to reject installation or other key to continue installation"
      pause
    else
      echo ViPNet SafeBoot update:
      type %InstallPkgDescriptionFile%
    endif
    set -v EspSearchDir %EfiDir%
  else
    echo ViPNet SafeBoot uninstallation
    if /i not %InteractivityMode% == not_interactive then
      # echo "Press 'q' key to reject uninstallation or other key to continue uninstallation"
      pause
    endif
    set -v EspSearchDir %EspItDir%
  endif
endif

# find ESP partition (by EFI\ or EFI\Infotecs\ directory)
for %j run (0 9 1)
  if /i not %InstallPkgPartition% == fs%j then
    if exist fs%j:\%EspSearchDir% then
      set -v EspPartition fs%j
      echo ESP partition found as %EspPartition%
      goto EspPartitionFound
    endif
  endif
endfor

# find first available (RW) partition for installation mode
if /i %InstallOrUninstallMode% == install then
  echo ESP partition not found. We will try to create ViPNet SafeBoot home directory on first available RW partition...
  for %k run (0 9 1)
    if /i not %InstallPkgPartition% == fs%k and exist fs%k:\ then
      # test current partition for write access
      # on some platforms echo in error case (RO fs) kills current script
      cp %InstallPkgPartition%:\startup.nsh fs%k:\test > NUL
      if not %lasterror% == 0x0 then
        echo fs%k directory seems to be read-only...
      else
        rm -q fs%k:\test
        set -v EspPartition fs%k
        echo ViPNet SafeBoot home directory will be created at %EspPartition%
        goto EspPartitionFound
      endif
    endif
  endfor
endif

if /i %ExtNtfsDriverLoaded% == false then
  if exist %ExtNtfsDriver% then
    if /i %InstallOrUninstallMode% == install then
      echo No one FAT RW partition found. Try to find EXT and NTFS partitions to install to...
    else
      echo FAT ESP partition not found. Try to find EXT or NTFS ESP partition...
    endif
    # unload default (RO) AMI NTFS driver if loaded
    if exist %DriverUnloader% then
      %DriverUnloader% "AMI NTFS Driver"
    endif
    load %ExtNtfsDriver% > NUL
    echo EXT and NTFS drivers (RW) successfully loaded
    map -r > NUL
    set -v ExtNtfsDriverLoaded true
    set -v ShowInstallerTitle false
    # after ExtNtfs driver loading we need to re-find installation partition
    goto FindInstallPkgPartition
  endif
endif

if /i %InstallOrUninstallMode% == install then
  echo No one RW partition found. Installation/update is not available...
else
  echo ESP partition not found. Uninstallation is not available...
endif
goto Exit

:EspPartitionFound

echo Installation package integrity verification...
%CheckPkgScript% %InstallPkgPartition% > %CheckPkgScriptLog%
if not %lasterror% == 0x0 then
  type %CheckPkgScriptLog%
  goto Exit
endif

if /i %InstallOrUninstallMode% == install then
  %InstallerScript% %InstallPkgPartition% %EspPartition% %InteractivityMode%
else
  %UninstallerScript% %InstallPkgPartition% %EspPartition% %InteractivityMode%
endif

:Exit
