# Script uninstalls ViPNet SafeBoot from SPI Flash BIOS region and ESP partition.
# Usage:
#  uninstaller.nsh <InstallPkgPartition> <EspPartition> (interactive | not_interactive)

echo -off

if x%1 == x or x%2 == x or x%3 == x then
  echo Invalid uninstaller.nsh arguments
  exit /b 1
endif
if /i not %3 == interactive and not %3 == not_interactive then
  echo Invalid uninstaller.nsh arguments
  exit /b 1
endif

set -v InstallPkgPartition %1
set -v EspPartition %2
set -v InteractivityMode %3

set -v InstallPkgDir itinstall
set -v ToolsDir %InstallPkgDir%\tools
set -v BiosTool %ToolsDir%\BiosTool.efi
set -v FlasherWrapper %InstallPkgDir%\flasher.nsh
set -v BiosToolIni %InstallPkgDir%\modules\biostool.ini
set -v FfsModulesDir %InstallPkgDir%\modules\ffs
set -v PlatformDir %InstallPkgDir%\platform
set -v BiosToolLog %PlatformDir%\biostool.log
set -v PrepBiosRegion %PlatformDir%\prep_fw_br.bin
set -v CurBiosRegion %PlatformDir%\cur_fw_br.bin
set -v ModBiosRegion %PlatformDir%\mod_fw_br.bin
set -v UninstallProfile delete_1_3_0
set -v EfiDir EFI
set -v EspItDir %EfiDir%\Infotecs
set -v EspItBackupDir %EfiDir%\InfotecsBackup

#%InstallPkgPartition%:

# TODO: implement uninstallation mode for UEFI installation

echo ESP backup phase...
if exist %EspPartition%:\%EspItDir% then
  if exist %EspPartition%:\%EspItBackupDir% then
    rm -q %EspPartition%:\%EspItBackupDir%\*
  else
    mkdir %EspPartition%:\%EspItBackupDir%
  endif
  cp -r -q %EspPartition%:\%EspItDir%\* %EspPartition%:\%EspItBackupDir%\ > NUL
  # TODO: create archive of EFI\Infotecs contents on installation disk
endif

echo Cleaning phase...
%InstallPkgDir%\cleaner.nsh %EspPartition% all

echo Firmware phase: uninstalling ViPNet SafeBoot modules from firmware image and writing it to SPI flash...
if exist %CurBiosRegion% then
  rm -q %CurBiosRegion%
endif
if exist %ModBiosRegion% then
  rm -q %ModBiosRegion%
endif

# 0. read current fw image (for delete modules from or for backup)
%FlasherWrapper% read %CurBiosRegion% %ToolsDir%

if not %lasterror% == 0x0 then
  echo Reading current firmware image error (%lasterror%)
  goto ExitOnErrorWithRecovery
endif
# workaround for BtFlash tool bug (not set lasterror in case of unsupported platform)
if not exist %CurBiosRegion% then
  echo Reading current firmware image error
  goto ExitOnErrorWithRecovery
endif

# 1. write prepared fw image if found
if exist %PrepBiosRegion% then
  %FlasherWrapper% write %PrepBiosRegion% %ToolsDir%

  if not %lasterror% == 0x0 then
    echo Writing prepared firmware image error (%lasterror%)
    goto ExitOnErrorWithRecovery
  endif

  goto EndOfUninstall
endif

# 2. delete ViPNet SafeBoot modules from fw image
echo UEFI modules deleting from firmware image process may be so long (several minutes). Please wait...
cd %ToolsDir%
# absolute paths used below because of 'cd' command above:
# it needs for BiosTool correct call - install.dat file must be in current directory
%InstallPkgPartition%:\%BiosTool% -i %InstallPkgPartition%:\%CurBiosRegion% -o %InstallPkgPartition%:\%ModBiosRegion% --profile %UninstallProfile% --configfile %InstallPkgPartition%:\%BiosToolIni% --pmdzdir %InstallPkgPartition%:\%FfsModulesDir% --debug > %InstallPkgPartition%:\%BiosToolLog%
cd \

# TODO?: type %BiosToolLog%

if not %lasterror% == 0x0 then
  echo Deleting ViPNet SafeBoot modules from firmware image error (%lasterror%)
  goto ExitOnErrorWithRecovery
endif
# workaround for BiosTool tool bug (not set lasterror in case of insufficient DXE volume free space)
if not exist %InstallPkgPartition%:\%ModBiosRegion% then
  echo Integrating ViPNet SafeBoot modules to firmware image error
  # workaround for setting lasterror in this case (0xE, EFI_NOT_FOUND)
  cp %InstallPkgPartition%:\%ModBiosRegion% %InstallPkgPartition%:\%ModBiosRegion% > NUL
  goto ExitOnErrorWithRecovery
endif

echo ViPNet SafeBoot modules deleted successfully from firmware image
#echo Press 'q' key to cancel firmware update or other key to continue
#pause -q

# 3. write modified fw image
%FlasherWrapper% write %ModBiosRegion% %ToolsDir%

if not %lasterror% == 0x0 then
  echo Writing modified firmware image error (%lasterror%)
  goto ExitOnErrorWithRecovery
endif

if exist %EspPartition%:\%EspItBackupDir% then
  rm -q %EspPartition%:\%EspItBackupDir% > NUL
endif

:EndOfUninstall
echo ViPNet SafeBoot uninstalled successfully
#if /i %InteractivityMode% == interactive then
if /i not %InteractivityMode% == not_interactive then
  echo Press 'q' key to cancel reboot or other key to reboot the system
  pause -q
else
  echo System will be reboot automatically after 10s
  stall 10000000
endif
reset -c "ViPNet SafeBoot uninstalled"

:ExitOnErrorWithRecovery
echo Restoring to ESP backup...
if exist %EspPartition%:\%EspItDir% then
  rm -q %EspPartition%:\%EspItDir% > NUL
endif
if exist %EspPartition%:\%EspItBackupDir% then
  mv %EspPartition%:\%EspItBackupDir% %EspPartition%:\%EspItDir% > NUL
endif

:ExitOnError
echo ViPNet SafeBoot uninstallation error
#if /i %InteractivityMode% == not_interactive then
if /i not %InteractivityMode% == interactive then
  echo System will be reboot automatically after 10s
  stall 10000000
  reset -c "ViPNet SafeBoot uninstall error"  
endif

:Exit
