# ViPNet SafeBoot installer startup script - to prepare environment to start Shell 2.1 BT.
# Executes by integrated Shell or by installer's Shell 1.0 (trampoline Shell).
# Usage:
#  startup.nsh [install | uninstall] [interactive | not_interactive]

echo -off

if x%1 == x then
  set -v InstallOrUninstallMode install
else
  # Shell 1.x not supports 'or' or 'and' operations in 'if' command, so...
  if /i not %1 == install then
    if /i not %1 == uninstall then
      echo Invalid startup.nsh arguments
      exit /b 1
    endif
  endif
  set -v InstallOrUninstallMode %1
endif

if x%2 == x then
  set -v InteractivityMode interactive
else
  # Shell 1.x not supports 'or' or 'and' operations in 'if' command, so...
  if /i not %2 == interactive then
    if /i not %2 == not_interactive then
      echo Invalid startup.nsh arguments
      exit /b 1
    endif
  endif
  set -v InteractivityMode %2
endif

set -v InstallPkgDir itinstall
set -v ToolsDir %InstallPkgDir%\tools
set -v EnglishDxe %ToolsDir%\EnglishDxe.efi
set -v RamDiskDxe %ToolsDir%\RamDiskDxe.efi
set -v Shell21BT %ToolsDir%\Shellx64_2.1_BT.efi
set -v InstallerMainScript %InstallPkgDir%\main.nsh

# find partition with installation package:
for %i run (0 9 1)
  if exist fs%i:\%InstallPkgDir% then
    set -v InstallPkgPartition fs%i
    goto InstallPkgPartitionFound
  endif
endfor

echo ViPNet SafeBoot installation package not found...
goto Exit

:InstallPkgPartitionFound
# echo ViPNet SafeBoot installation partition found as %InstallPartition%

# Shell 2.1 BT depends on EnglishDxe on some platforms (with UEFI 2.3.1?).
# BiosTool already depends on RamDiskDxe, but it hangs the system when loaded from Shell 2.1 BT
# on some platforms, so load it here...
load %InstallPkgPartition%:\%EnglishDxe%
load %InstallPkgPartition%:\%RamDiskDxe%

if /i %InteractivityMode% == interactive then
  %InstallPkgPartition%:\%Shell21BT% -delay 0 -nomap -nointerrupt %InstallerMainScript% %InstallOrUninstallMode% %InteractivityMode%
else
  %InstallPkgPartition%:\%Shell21BT% -delay 0 -nomap -nointerrupt -noconsolein %InstallerMainScript% %InstallOrUninstallMode% %InteractivityMode%
endif

:Exit
